@@ -269,6 +269,11 @@ def parse_vmoddf(vmoddf):
 
 
 def check_string_for_seq(redstring, pair):
+    if redstring == "All":
+        return True
+    if redstring == "None":
+        return False
+
     code = "Seq" + str(pair)
     if code in redstring:
         return True
@@ -276,6 +281,47 @@ def check_string_for_seq(redstring, pair):
         return False
 
 
+def calc_bispecific_correct(row, a_code="BsAb (Correct)", b_code="LC1 Mispair (Incorrect)",
+                            c_code="LC2 Mispair (Incorrect)"):
+    """
+    Calculate the correct bispecific pairing from three columns of heights.
+    Ref: http://dx.doi.org/10.1080/19420862.2016.1232217
+    :param row: df row with the three columns
+    :param a_code: the code for the first column with the correct pairing
+    :param b_code: the code for the second column with the incorrect pairing
+    :param c_code: the code for the third column with the incorrect pairing
+    :return: x, y, the fraction of the a peak that is correctly paired and light chain scrambled, respectively.
+    """
+    if a_code not in row.keys() or b_code not in row.keys() or c_code not in row.keys():
+        return row
+    # Get Heights
+    a = row[a_code.lower() + " Height"]
+    b = row[b_code.lower() + " Height"]
+    c = row[c_code.lower() + " Height"]
+
+    # Normalize
+    s = np.sum([a, b, c])
+    if s == 0:
+        return row
+    a /= s
+    b /= s
+    c /= s
+
+    # Calculate
+    d = (a / 2.) ** 2 - (b * c)
+    if d > 0:
+        x = (a / 2.) + np.sqrt(d)
+    else:
+        x = (a / 2.)
+    y = a - x
+
+    # Set
+    row["BsAb Pairing Calculated (%)"] = x
+    row["Light Chain Scrambled (%)"] = y
+
+    return row
+
+
 known_labels = ["Correct", "Incorrect", "Ignore"]
 
 
@@ -302,7 +348,7 @@ def calc_pairs(row, include_seqs=False, remove_zeros=True, fmoddf=None):
     # Try to get reduced things
     if "Apply Fixed Mods" in row.keys():
         modstring = str(row["Apply Fixed Mods"])
-        print(modstring)
+        # print(modstring)
 
     total_mod_mass, total_mod_name = parse_fmoddf(fmoddf)
 
@@ -418,10 +464,26 @@ def UPP_check_peaks(row, pks, tol, vmoddf=None, fmoddf=None, favor="Closest"):
         favor = row["Favored Match"]
         print("Favoring:", favor)
 
+    # Get the global fixed mod
+    globalfixedmod = 0
+    if "Global Fixed Mod" in row.keys():
+        try:
+            val = float(row["Global Fixed Mod"])
+            if not math.isnan(val):
+                globalfixedmod = val
+                print("Global Fixed Mod:", globalfixedmod)
+        except Exception:
+            globalfixedmod = 0
+
     # Calculate the potential pairs
     pmasses, plabels = calc_pairs(row, fmoddf=fmoddf)
+    # Add the global fixed mod
+    pmasses += globalfixedmod
     # print(peakmasses)
     print(np.transpose([pmasses, plabels]))
+    if len(pmasses) == 0:
+        print("No masses found. Exiting Pair Mode.")
+        return row
     plabelints = np.zeros(len(plabels))
 
     # Get Variable Mods
@@ -570,4 +632,6 @@ def UPP_check_peaks(row, pks, tol, vmoddf=None, fmoddf=None, favor="Closest"):
     row["incorrect % Matched Only"] = percents2[1]
     row["Matches"] = matchstring
 
+    row = calc_bispecific_correct(row)
+
     return row
