@@ -59,6 +59,7 @@ class UniDecConfig(object):
         self.outfname = ""
         self.mfile = "mass.dat"
         self.manualfile = "man.dat"
+        self.smashfile = "smash.dat"
         self.confname = "conf.dat"
         self.hdf_file = "default.hdf5"
         self.ofile = "ofile.dat"
@@ -165,6 +166,8 @@ class UniDecConfig(object):
         self.matchlist = []
         self.oligomerlist = []
         self.manuallist = []
+        self.smashlist = []
+        self.smashflag = 0
         self.zoffs = []
         self.smashrange = []
         self.massoffset = 0
@@ -317,6 +320,8 @@ class UniDecConfig(object):
         self.matchlist = []
         self.oligomerlist = []
         self.manuallist = []
+        self.smashlist = []
+        self.smashflag = 0
         self.zoffs = []
         self.smashrange = []
         self.massoffset = 0
@@ -465,6 +470,7 @@ class UniDecConfig(object):
         f.write("psfun " + str(self.psfun) + "\n")
         f.write("zpsfun " + str(self.psfunz) + "\n")
         f.write("discreteplot " + str(self.discreteplot) + "\n")
+        f.write("smashflag " + str(self.smashflag) + "\n")
         f.write("massub " + str(self.massub) + "\n")
         f.write("masslb " + str(self.masslb) + "\n")
         f.write("msig " + str(self.msig) + "\n")
@@ -560,10 +566,11 @@ class UniDecConfig(object):
                 f.write("gasmass " + str(self.gasmass) + "\n")
 
         f.close()
+        # Export Mass List
         if not ud.isempty(self.masslist):
             ud.dataexport(self.masslist, self.mfile)
+        # Export Manual List
         if not ud.isempty(self.manuallist):
-            # print self.manuallist
             self.manuallist = np.array(self.manuallist)
             if self.imflag == 0:
                 if self.manuallist.shape[1] == 3:
@@ -577,6 +584,23 @@ class UniDecConfig(object):
                 else:
                     print("Manual List Shape is wrong. Try using manual list tool again.")
                     print(self.manuallist.shape)
+        # Export Smash list
+        if not ud.isempty(self.smashlist):
+            # print self.smashlist
+            self.smashlist = np.array(self.smashlist)
+            if self.imflag == 0 and self.cdmsflag == 0:
+                if self.smashlist.shape[1] == 2:
+                    ud.dataexport(self.smashlist, self.smashfile)
+                else:
+                    print("Manual List Shape is wrong. Try using manual list tool again.")
+                    print(self.smashlist.shape)
+            else:
+                if self.smashlist.shape[1] == 4:
+                    ud.dataexport(self.smashlist, self.smashfile)
+                else:
+                    print("Manual List Shape is wrong. Try using manual list tool again.")
+                    print(self.smashlist.shape)
+
         if not ud.isempty(self.oligomerlist):
             np.savetxt(self.ofile, self.oligomerlist, fmt='%s')
 
@@ -639,6 +663,8 @@ class UniDecConfig(object):
                             self.psfunz = ud.string_to_int(line.split()[1])
                         if line.startswith("discreteplot"):
                             self.discreteplot = ud.string_to_int(line.split()[1])
+                        if line.startswith("smashflag"):
+                            self.smashflag = ud.string_to_int(line.split()[1])
                         if line.startswith("massub"):
                             self.massub = ud.string_to_value(line.split()[1])
                         if line.startswith("masslb"):
@@ -785,6 +811,7 @@ class UniDecConfig(object):
             f.close()
             self.endz = self.startz + self.numz - 1
 
+            # Import massfile
             if os.path.isfile(self.mfile):
                 self.masslist = np.loadtxt(self.mfile)
                 if self.masslist.size == 1:
@@ -792,6 +819,7 @@ class UniDecConfig(object):
             else:
                 self.masslist = np.array([])
 
+            # Import Ofile
             if os.path.isfile(self.ofile):
                 self.oligomerlist = ofile_reader(self.ofile)
                 if self.oligomerlist.shape == (4,) or self.oligomerlist.shape == (5,):
@@ -799,6 +827,7 @@ class UniDecConfig(object):
             else:
                 self.oligomerlist = np.array([])
 
+            # Import manual file
             if os.path.isfile(self.manualfile):
                 self.manuallist = np.loadtxt(self.manualfile)
                 if self.imflag == 0:
@@ -810,6 +839,18 @@ class UniDecConfig(object):
             else:
                 self.manuallist = np.array([])
 
+            # Import smash file
+            if os.path.isfile(self.smashfile):
+                self.smashlist = np.loadtxt(self.smashfile)
+                if self.imflag == 0 and self.cdmsflag == 0:
+                    if self.smashlist.shape == (2,):
+                        self.smashlist = np.array([self.smashlist])
+                else:
+                    if self.smashlist.shape == (4,):
+                        self.smashlist = np.array([self.smashlist])
+            else:
+                self.smashlist = np.array([])
+
     def get_config_dict(self):
         if self.metamode != -2:
             self.linflag = 2
@@ -874,7 +915,7 @@ class UniDecConfig(object):
 
         for key, value in cdict.items():
             try:
-                #if value is None:
+                # if value is None:
                 #    value = ""
                 config_group.attrs[key] = value
             except Exception as e:
@@ -1023,6 +1064,7 @@ class UniDecConfig(object):
         self.confname = self.outfname + "_conf.dat"
         self.mfile = self.outfname + "_mfile.dat"
         self.manualfile = self.outfname + "_manualfile.dat"
+        self.smashfile = self.outfname + "_smashfile.dat"
         self.ofile = self.outfname + "_ofile.dat"
         self.matchfile = self.outfname + "_match.dat"
         self.peaksfile = self.outfname + "_peaks.dat"
